/*
 * voshtomoc.h
 * pidgin plugin
 *
 * This a plugin for pidgin to run shell commands through an IM window
 *
 * Copyright (C) 2007 Ioan A. Sucan (http://ioan.sucan.info)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; This document is under the scope of
 * the version 2 of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program (see COPYING); if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef VOSHTOMOC_H_
#define VOSHTOMOC_H_

#define PURPLE_PLUGINS

#include <glib.h>

#include <libpurple/conversation.h>
#include <libpurple/debug.h>
#include <libpurple/status.h>
#include <libpurple/signals.h>
#include <libpurple/util.h>
#include <libpurple/server.h>
#include <libpurple/cmds.h>
#include <libpurple/log.h>
#include <libpurple/version.h>


#include <pidgin/gtkplugin.h>
#include <pidgin/gtkprefs.h>
#include <pidgin/gtkutils.h>

#include <sys/types.h>
#include <unistd.h>
#include <sys/time.h>
#include <time.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <signal.h>
#include <math.h>

/* plugin version */
#define PVERSION "0.3"

/* maximum message size when we send data */
#define MAX_MSG_SIZE 448           


/* data for programs we may run */

typedef struct 
{
    char  *name;          /* the name of the program to run       */
    int    n_allowed;     /* number of allowed users              */
    char **allowed;       /* the allowed users                    */
    int    is_cmd;        /* parse as command (!CMD[...]) if true */
    int    send_name;     /* send the user name as well if true   */
    int    when_away;     /* active only when away if true        */
    float  wait_time;     /* when sending data to a program, wait a
			     while (seconds) until reading output data */    
    int    active;        /* ignore entry if this is 0            */    
} program_t;


typedef struct
{
    int rwpipe[2];   /* the pipes used for communicating with child process; write to 1, read from 0 */
    pid_t pid;       /* the pid of the child process */
    int prog;        /* the number of the program_t structure used to run the child process */
    int running;     /* true if program is running */
} program_instance_t;


/* data for active users */

typedef struct
{
    char *name;              /* the alias for the user in question (what is displayed by pidgin) */
    int index;               /* the index of the active program */
    int nprogs;              /* number of running programs */
    program_instance_t *prg; /* list of program instances */
} user_t;


/* constants for command processing */
static const int   CMD_SEP_COUNT  = 4;          /* number of possible separator symbols */
static const char *CMD_BEG        = "([<{";     /* starting separator */
static const char *CMD_END        = ")]>}";     /* terminating separator */
static const char *CMD_PREFIX     = "!CMD";     /* command marker */


#endif
